dnl #########################################################################
dnl Synopsis:
dnl		AC_PATH_QT
dnl	Purpose:
dnl		To seek and find your Qt installation
dnl Access:
dnl
dnl	--with-qt-dir           where the root of qt is installed (/usr/local/qt)	
dnl --with-qt-include       where the qt includes are. (/usr/local/qt/include)
dnl --with-qt-lib           where the qt library is installed. (/usr/local/qt/lib)
dnl
dnl Defines: (to DEFS or config.h)
dnl		None
dnl	Substitutions: (to Makefile from Makefile.in)
dnl		QT_CFLAGS - Path to Qt includes (-Iwhateverincdir)
dnl		QT_LIBS   - Linkpath and libraryname (-Lwhateverlibdir -lqt)
dnl Requirements:
dnl		AC_PATH_XTRA must be called first
dnl	Returns:
dnl		values in QT_CFLAGS and QT_LIBS, or configure will stop on error
dnl #########################################################################

AC_DEFUN(AC_PATH_QT,
[
AC_PROVIDE([$0])
AC_REQUIRE([AC_PATH_XTRA])

ac_cv_with_qt_dir=
ac_cv_with_qt_lib=
ac_cv_with_qt_inc=
QT_CFLAGS=
QT_LIBS=

AC_ARG_WITH(qt-dir,
    [  --with-qt-dir           where the root of qt is installed (/usr/local/qt) ],
    [  ac_cv_with_qt_dir="$withval" ])

AC_ARG_WITH(qt-include,
    [  --with-qt-include       where the qt includes are. (/usr/local/qt/include) ],
    [  ac_cv_with_qt_inc="$withval" ])
    
AC_ARG_WITH(qt-lib,
    [  --with-qt-lib           where the qt library is installed. (/usr/local/qt/lib)],
    [  ac_cv_with_qt_lib="$withval" ])
    
dnl try to set some paths

AC_MSG_CHECKING("for Qt location")
if test ! -n "$ac_cv_with_qt_dir"; then
	if test -n "${QTDIR}" && test -d "${QTDIR}"; then
		ac_cv_with_qt_dir="${QTDIR}" 
	elif test -d "/usr/local/qt"; then
		ac_cv_with_qt_dir="/usr/local/qt" 
	elif test -d "/usr/share/qt"; then
		ac_cv_with_qt_dir="/usr/share/qt" 
	elif test -n "${QTDIR}"; then
		AC_MSG_WARN(["Can\'t find Qt in either $QTDIR, /usr/local or /usr/share"])
	else
		AC_MSG_WARN(["Can\'t find Qt in either /usr/local or /usr/share"])
	fi
fi
AC_MSG_RESULT("$ac_cv_with_qt_dir")

dnl check for libraries and includes

AC_MSG_CHECKING("for Qt libraries and includes")
if test ! -n "$ac_cv_with_qt_lib"; then
	ac_cv_with_qt_lib="$ac_cv_with_qt_dir/lib"
fi
if test ! -n "$ac_cv_with_qt_inc"; then
	ac_cv_with_qt_inc="$ac_cv_with_qt_dir/include"
fi
AC_MSG_RESULT(["libraries ${ac_cv_with_qt_lib}, includes ${ac_cv_with_qt_inc}"])

AC_PATH_PROG(MOC, moc, no)
if test "$MOC" = no; then
    AC_MSG_ERROR("You need to install Qt first: can\'t find the meta object compiler")
fi

SAVE_LIBS="${LIBS}"

AC_CHECK_LIB(qt, main,
[
	QT_LIBS="-L${ac_cv_with_qt_lib} -lqt"
	AC_SUBST(QT_LIBS)
],
[
    AC_MSG_ERROR(["You need to install Qt first: can\'t find the Qt library"])
],
[-L$ac_cv_with_qt_lib $X_LIBS $X_PRE_LIBS -lX11 $X_EXTRA_LIBS])

LIBS="${SAVE_LIBS}"
QT_CFLAGS="-I${ac_cv_with_qt_inc}"
AC_SUBST(QT_CFLAGS)

])





dnl #########################################################################
dnl Synopsis:
dnl		AC_PATH_GL
dnl	Purpose:
dnl		To seek and find your Qt installation
dnl Access:
dnl
dnl	--with-gl-dir           where the root of gl is installed (/usr/local/gl)	
dnl --with-gl-include       where the gl includes are. (/usr/local/gl/include)
dnl --with-gl-lib           where the gl library is installed. (/usr/local/gl/lib)
dnl --enable-mesagl         If you always want MesaGL instead of just GL
dnl Defines: (to DEFS or config.h)
dnl		None
dnl	Substitutions: (to Makefile from Makefile.in)
dnl		GL_CFLAGS - Path to Qt includes (-Iwhateverincdir)
dnl		GL_LIBS   - Linkpath and libraryname (-Lwhateverlibdir -lgl)
dnl Requirements:
dnl		AC_PATH_XTRA must be called first, for now
dnl	Returns:
dnl		values in GL_CFLAGS and GL_LIBS, or configure will stop on error
dnl #########################################################################

AC_DEFUN(AC_PATH_GL,
[
AC_PROVIDE([$0])
AC_REQUIRE([AC_PATH_XTRA])

ac_cv_with_gl_dir=
ac_cv_with_gl_lib=
ac_cv_with_gl_inc=
ac_cv_enable_mesagl=

GL_CFLAGS=
GL_LIBS=

AC_ARG_WITH(gl-dir,
    [  --with-gl-dir           where the root of gl is installed (/usr/local/gl) ],
    [  ac_cv_with_gl_dir="$withval" ])

AC_ARG_WITH(gl-include,
    [  --with-gl-include       where the gl includes are. (/usr/local/gl/include) ],
    [  ac_cv_with_gl_inc="$withval" ])
    
AC_ARG_WITH(gl-lib,
    [  --with-gl-lib           where the gl library is installed. (/usr/local/gl/lib)],
    [  ac_cv_with_gl_lib="$withval" ])

AC_ARG_ENABLE(mesagl,
    [  --enable-mesagl         If you always want MesaGL instead of just GL ],
    [  ac_cv_enable_mesagl="$enableval" ],
    [  ac_cv_enable_mesagl="no" ])
    

AC_MSG_CHECKING("we like Mesa GL instead of just OpenGL")
AC_MSG_RESULT("$ac_cv_enable_mesagl")

dnl try to set some paths

AC_MSG_CHECKING("for Gl location")
if test ! -n "$ac_cv_with_gl_dir"; then
	if test -n "${GLDIR}" && test -d "${GLDIR}"; then
		ac_cv_with_gl_dir="${GLDIR}" 
	elif test -d "/usr/local/gl"; then
		ac_cv_with_gl_dir="/usr/local/gl" 
	elif test -d "/usr/share/gl"; then
		ac_cv_with_gl_dir="/usr/share/gl" 
	elif test -n "${GLDIR}"; then
		AC_MSG_WARN(["Can\'t find Gl in either $GLDIR, /usr/local or /usr/share"])
	else
		AC_MSG_WARN(["Can\'t find Gl in either /usr/local or /usr/share"])
	fi
fi
AC_MSG_RESULT("$ac_cv_with_gl_dir")

dnl check for libraries and includes

AC_MSG_CHECKING("for Gl libraries and includes")
if test ! -n "$ac_cv_with_gl_lib" && test -n "$ac_cv_with_gl_dir"; then
	ac_cv_with_gl_lib="$ac_cv_with_gl_dir/lib"
fi
if test ! -n "$ac_cv_with_gl_inc" && test -n "$ac_cv_with_gl_dir"; then
	ac_cv_with_gl_inc="$ac_cv_with_gl_dir/include"
fi
AC_MSG_RESULT(["libraries ${ac_cv_with_gl_lib}, includes ${ac_cv_with_gl_inc}"])

SAVE_LIBS="${LIBS}"
if test ! -n "${ac_cv_with_gl_lib}"; then
	ac_cv_with_gl_lib="."
fi

test "$ac_cv_enable_mesagl" = no; then
	AC_CHECK_LIB(GL, main,
	[
		if test "${ac_cv_with_gl_lib}" = "."; then
			GL_LIBS="-lGL"
		else
			GL_LIBS="-L${ac_cv_with_gl_lib} -lGL"
		fi
		AC_SUBST(GL_LIBS)
	],
	[
		GL_LIBS=no
	],
	[-L$ac_cv_with_gl_lib $X_LIBS $X_PRE_LIBS -lX11 $X_EXTRA_LIBS])
fi
if test "$ac_cv_enable_mesagl" = yes || test "${GL_LIBS}" = no; then
	AC_MSG_WARN(["Can\'t  link with Gl, trying the Mesa library..."])
	AC_CHECK_LIB(MesaGL, main,
	[
		if test "${ac_cv_with_gl_lib}" = "."; then
			GL_LIBS="-lMesaGL"
		else
			GL_LIBS="-L${ac_cv_with_gl_lib} -lMesaGL"
		fi
		AC_SUBST(GL_LIBS)
	],
	[
    	AC_MSG_ERROR(["You need to install \(Mesa\) OpenGL first: can\'t find either the GL or MesaGL library"])
	], [-L$ac_cv_with_gl_lib $X_LIBS $X_PRE_LIBS -lX11 $X_EXTRA_LIBS])
fi

LIBS="${SAVE_LIBS}"
GL_CFLAGS="-I${ac_cv_with_gl_inc}"
AC_SUBST(GL_CFLAGS)

])


AC_DEFUN(AC_SYS_DL,
[
ac_cv_dl_underscore=
ac_cv_dl_extension=
ac_cv_dl_cflags=
ac_cv_dl_lflags=
ac_cv_dl_dllcmd=
ac_cv_dl_rtld_def=
ac_cv_dl_iface=

dnl ##
dnl #if dynamic loading interface is dlopen (SunOS style)
dnl ##

AC_CHECK_HEADERS(dlfcn.h dl.h,[break],[
	AC_MSG_WARN(["Don't know how to link dynamicly on your system"])
	AC_DEFINE(NO_DYNAMIC_LINKING)
])

if test -n "${HAVE_DLFCN_H}"; then
	AC_MSG_CHECKING("RTLD_LAZY define in dlfcn.h ...")
	AC_EGREP_CPP(yes,
	[ #include <dlfcn.h>
	#ifdef RTLD_LAZY
	 yes
	#endif
	], ac_cv_dl_rtld_def=yes,ac_cv_dl_rtld_def=no)

	if test "${ac_cv_dl_rtld_def}" = "yes"; then
	    AC_DEFINE_QUOTED(RTLD_LAZY,1)
	fi
	AC_MSG_RESULT("${ac_cv_dl_rtld_def}")
	
	dnl Start of dlsym needs leading underscore test

	dnl borrowed from kaffe, a free java implementation
	dnl Some dynamic library need an underscore on the loading name, some don't

	AC_CACHE_CHECK(for underscore in dlsym, ac_cv_dl_underscore,
	echo "#define _LIBC_ \"`ls /lib/lib*c.so* /usr/lib/lib*c.so.* 2>/dev/null | head -1`\"" >> confdefs.h
	AC_TRY_RUN(main()
	{[void* lib = (void*)dlopen(_LIBC_);
	  if (dlsym(lib, "_printf") != 0) { exit(0); } else { exit(1); } }],
	ac_cv_dl_underscore=yes, ac_cv_dl_underscore=no, ac_cv_dl_underscore=cross))
	if test "$ac_cv_dl_underscore" = "yes"; then
	    AC_DEFINE(HAVE_DLSYM_UNDERSCORE)

	dnl try to figure out compilerflags, linkerflags, etc...

	dnl ##
	dnl #End dlfcn.h
	dnl ##


elif test -n "${HAVE_DL_H}"; then
	dnl HP-UX flags
fi
])
